@@ -434,8 +434,8 @@ our %Modules = (
     },
 
     'experimental' => {
-        'DISTRIBUTION' => 'LEONT/experimental-0.034.tar.gz',
-        'SYNCINFO'     => 'mauke on Sun Jan 12 01:01:29 2025',
+        'DISTRIBUTION' => 'LEONT/experimental-0.035.tar.gz',
+        'SYNCINFO'     => 'jkeenan on Thu May  1 06:44:57 2025',
         'FILES'        => q[cpan/experimental],
         'EXCLUDED'     => [qr{^xt/}],
     },
@@ -494,7 +494,7 @@ our %Modules = (
     },
 
     'ExtUtils::MakeMaker' => {
-        'DISTRIBUTION' => 'BINGOS/ExtUtils-MakeMaker-7.74.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/ExtUtils-MakeMaker-7.76.tar.gz',
         'SYNCINFO'     => 'yorton on Sun Mar 26 16:20:23 2023',
         'FILES'        => q[cpan/ExtUtils-MakeMaker],
         'EXCLUDED'     => [
@@ -528,7 +528,7 @@ our %Modules = (
     },
 
     'ExtUtils::ParseXS' => {
-        'DISTRIBUTION' => 'LEONT/ExtUtils-ParseXS-3.51.tar.gz',
+        'DISTRIBUTION' => 'LEONT/ExtUtils-ParseXS-3.57.tar.gz',
         'FILES'        => q[dist/ExtUtils-ParseXS],
     },
 
@@ -832,7 +832,7 @@ our %Modules = (
     },
 
     'Module::CoreList' => {
-        'DISTRIBUTION' => 'BINGOS/Module-CoreList-5.20250321.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/Module-CoreList-5.20250421.tar.gz',
         'FILES'        => q[dist/Module-CoreList],
     },
 
@@ -916,7 +916,8 @@ our %Modules = (
     },
 
     'perlfaq' => {
-        'DISTRIBUTION' => 'ETHER/perlfaq-5.20240218.tar.gz',
+        'DISTRIBUTION' => 'ETHER/perlfaq-5.20250619.tar.gz',
+        'SYNCINFO'     => 'ether on Wed Jun 18 20:32:25 2025',
         'FILES'        => q[cpan/perlfaq],
         'EXCLUDED'     => [ qr/^inc/, qr/^xt/, qr{^t/00-} ],
     },
@@ -971,8 +972,7 @@ our %Modules = (
         'EXCLUDED' => [
             qw{.ChangeLog.swp},
             qr{^\.github/}
-	],
-        'CUSTOMIZED'   => ['lib/Pod/Simple/HTMLLegacy.pm'],
+        ],
     },
 
     'Pod::Usage' => {
