@@ -21,11 +21,11 @@ TAP::Parser::SourceHandler::Perl - Stream TAP from a Perl executable
 
 =head1 VERSION
 
-Version 3.44
+Version 3.50
 
 =cut
 
-our $VERSION = '3.44';
+our $VERSION = '3.50';
 
 =head1 SYNOPSIS
 
@@ -77,7 +77,9 @@ sub can_handle {
     return 0 unless $meta->{is_file};
     my $file = $meta->{file};
 
-    if ( my $shebang = $file->{shebang} ) {
+    my $shebang = $file->{shebang} || '';
+
+    if ( $shebang =~ /^#!/ ) {
         return 0.9 if $shebang =~ /^#!.*\bperl/;
 
         # We favour Perl as the interpreter for any shebang to preserve
@@ -90,7 +92,8 @@ sub can_handle {
     return 0.8 if $file->{lc_ext} eq '.t';    # vote higher than Executable
     return 0.9 if $file->{lc_ext} eq '.pl';
 
-    return 0.75 if $file->{dir} =~ /^t\b/;    # vote higher than Executable
+    my @dirs = File::Spec->splitdir($file->{dir});
+    return 0.75 if scalar(@dirs) && $dirs[0] eq 't';    # vote higher than Executable
 
     # backwards compat, always vote:
     return 0.25;
